@@ -15,11 +15,12 @@
 package providers
 
 import (
+	"errors"
 	"fmt"
 	"testing"
 
 	"github.com/blang/semver"
-	"github.com/pkg/errors"
+
 	"github.com/stretchr/testify/assert"
 
 	"github.com/pulumi/pulumi/sdk/v3/go/common/diag"
