@@ -1,4 +1,4 @@
-// Copyright 2016-2018, Pulumi Corporation.
+// Copyright 2016-2021, Pulumi Corporation.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -248,14 +248,19 @@ export function call<T>(tok: string, props: Inputs, res?: Resource): Output<T> {
             // Construct a provider reference from the given provider, if one is available on the resource.
             let provider: string | undefined = undefined;
             let version: string | undefined = undefined;
+            let pluginDownloadUrl: string | undefined = undefined;
             if (res) {
                 if (res.__prov) {
                     provider = await ProviderResource.register(res.__prov);
                 }
                 version = res.__version;
+                pluginDownloadUrl = res.__pluginDownloadURL;
             }
 
-            const [serialized, propertyDepsResources] = await serializePropertiesReturnDeps(`call:${tok}`, props);
+            // We keep output values when serializing inputs for call.
+            const [serialized, propertyDepsResources] = await serializePropertiesReturnDeps(`call:${tok}`, props, {
+                keepOutputValues: true,
+            });
             log.debug(`Call RPC prepared: tok=${tok}` + excessiveDebugOutput ? `, obj=${JSON.stringify(serialized)}` : ``);
 
             const req = await createCallRequest(tok, serialized, propertyDepsResources, provider, version);
@@ -384,7 +389,8 @@ function createOutput<T>(label: string):
 }
 
 async function createCallRequest(tok: string, serialized: Record<string, any>,
-                                 serializedDeps: Map<string, Set<Resource>>, provider?: string, version?: string) {
+                                 serializedDeps: Map<string, Set<Resource>>, provider?: string,
+                                 version?: string, pluginDownloadURL?: string) {
     if (provider !== undefined && typeof provider !== "string") {
         throw new Error("Incorrect provider type.");
     }
@@ -396,6 +402,7 @@ async function createCallRequest(tok: string, serialized: Record<string, any>,
     req.setArgs(obj);
     req.setProvider(provider);
     req.setVersion(version || "");
+    req.setPlugindownloadurl(pluginDownloadURL || "");
 
     const argDependencies = req.getArgdependenciesMap();
     for (const [key, propertyDeps] of serializedDeps) {
